@@ -3,6 +3,7 @@
 from __future__ import annotations
 
 import asyncio
+import contextlib
 import importlib
 import importlib.util
 import logging
@@ -13,6 +14,8 @@ import threading
 from pathlib import Path
 from typing import Any
 
+import typer
+
 from hud.utils.hud_console import HUDConsole
 
 hud_console = HUDConsole()
@@ -26,6 +29,7 @@ def show_dev_server_info(
     interactive: bool,
     env_dir: Path | None = None,
     new: bool = False,
+    docker_mode: bool = False,
 ) -> str:
     """Show consistent server info for both Python and Docker modes.
 
@@ -54,7 +58,15 @@ def show_dev_server_info(
     if transport == "http":
         hud_console.section_title("Quick Links")
         hud_console.info(f"{hud_console.sym.ITEM} Docs: http://localhost:{port}/docs")
-        hud_console.info(f"{hud_console.sym.ITEM} Cursor: {cursor_deeplink}")
+        hud_console.info(f"{hud_console.sym.ITEM} Cursor:")
+        # Display the Cursor link on its own line to prevent wrapping
+        hud_console.link(cursor_deeplink)
+
+        # Show eval endpoint if in Docker mode
+        if docker_mode:
+            hud_console.info(
+                f"{hud_console.sym.ITEM} Eval API: http://localhost:{port}/eval (POST)"
+            )
 
         # Check for VNC (browser environment)
         if env_dir and (env_dir / "environment" / "server.py").exists():
@@ -237,7 +249,7 @@ async def run_mcp_module(
 
                 from hud.cli.flows.dev import create_dynamic_trace
 
-                live_trace_url = await create_dynamic_trace(
+                _, live_trace_url = await create_dynamic_trace(
                     mcp_config=local_mcp_config,
                     build_status=False,
                     environment_name=mcp_server.name or "mcp-server",
@@ -510,6 +522,9 @@ def run_docker_dev_server(
     new: bool = False,
 ) -> None:
     """Run MCP server in Docker with volume mounts, expose via local HTTP proxy."""
+    import atexit
+    import signal
+
     import typer
     import yaml
 
@@ -522,6 +537,69 @@ def run_docker_dev_server(
 
     cwd = Path.cwd()
 
+    # Container name will be set later and used for cleanup
+    container_name: str | None = None
+    cleanup_done = False
+
+    def cleanup_container() -> None:
+        """Clean up Docker container on exit."""
+        nonlocal cleanup_done
+        if cleanup_done or not container_name:
+            return
+
+        cleanup_done = True
+        hud_console.debug(f"Cleaning up container: {container_name}")
+
+        # Check if container is still running
+        try:
+            result = subprocess.run(  # noqa: S603
+                ["docker", "ps", "-q", "-f", f"name={container_name}"],  # noqa: S607
+                stdout=subprocess.PIPE,
+                stderr=subprocess.DEVNULL,
+                text=True,
+                timeout=5,
+            )
+            if not result.stdout.strip():
+                # Container is not running, just try to remove it
+                subprocess.run(  # noqa: S603
+                    ["docker", "rm", "-f", container_name],  # noqa: S607
+                    stdout=subprocess.DEVNULL,
+                    stderr=subprocess.DEVNULL,
+                    timeout=5,
+                )
+                return
+        except Exception:  # noqa: S110
+            pass
+
+        try:
+            # First try to stop gracefully
+            subprocess.run(  # noqa: S603
+                ["docker", "stop", container_name],  # noqa: S607
+                stdout=subprocess.DEVNULL,
+                stderr=subprocess.DEVNULL,
+                timeout=10,
+            )
+            hud_console.debug(f"Container {container_name} stopped successfully")
+        except subprocess.TimeoutExpired:
+            # Force kill if stop times out
+            hud_console.debug(f"Container {container_name} stop timeout, forcing kill")
+            with contextlib.suppress(Exception):
+                subprocess.run(  # noqa: S603
+                    ["docker", "kill", container_name],  # noqa: S607
+                    stdout=subprocess.DEVNULL,
+                    stderr=subprocess.DEVNULL,
+                    timeout=5,
+                )
+
+    # Set up signal handlers for cleanup
+    def signal_handler(signum: int, frame: Any) -> None:
+        cleanup_container()
+        sys.exit(0)
+
+    signal.signal(signal.SIGTERM, signal_handler)
+    if sys.platform != "win32":
+        signal.signal(signal.SIGHUP, signal_handler)
+
     # Find environment directory (current or parent with hud.lock.yaml)
     env_dir = cwd
     lock_path = env_dir / "hud.lock.yaml"
@@ -562,10 +640,14 @@ def run_docker_dev_server(
     base_name = image_name.replace(":", "-").replace("/", "-")
     container_name = f"{base_name}-dev-{pid}"
 
+    # Register cleanup function with atexit
+    atexit.register(cleanup_container)
+
     # Build docker run command with volume mounts and folder-mode envs
     from .utils.docker import create_docker_run_command
 
     base_args = [
+        "--rm",  # Automatically remove container when it stops
         "--name",
         container_name,
         "-v",
@@ -608,7 +690,7 @@ def run_docker_dev_server(
                     "headers": {},
                 }
             }
-            live_trace_url = _asy.run(
+            _, live_trace_url = _asy.run(
                 create_dynamic_trace(
                     mcp_config=local_mcp_config,
                     build_status=True,
@@ -643,6 +725,7 @@ def run_docker_dev_server(
             interactive=interactive,
             env_dir=env_dir,
             new=new,
+            docker_mode=True,
         )
         hud_console.dim_info(
             "",
@@ -661,13 +744,38 @@ def run_docker_dev_server(
     # Create and run proxy with HUD helpers
     async def run_proxy() -> None:
         from fastmcp import FastMCP
+        from fastmcp.server.proxy import ProxyClient
 
-        # Create FastMCP proxy to Docker stdio
-        fastmcp_proxy = FastMCP.as_proxy(mcp_config, name="HUD Docker Dev Proxy")
+        # Create ProxyClient without custom log handler since we capture Docker logs directly
+        proxy_client = ProxyClient(mcp_config, name="HUD Docker Dev Proxy")
+
+        # Extract container name from docker args and store for logs endpoint
+        docker_cmd = mcp_config["docker"]["args"]
+        container_name = None
+        for i, arg in enumerate(docker_cmd):
+            if arg == "--name" and i + 1 < len(docker_cmd):
+                container_name = docker_cmd[i + 1]
+                break
+
+        if container_name:
+            # Store container name for logs endpoint to use
+            os.environ["_HUD_DEV_DOCKER_CONTAINER"] = container_name
+            hud_console.debug(f"Docker container: {container_name}")
+
+        # Store the docker mcp_config for the eval endpoint
+        import json
+
+        os.environ["_HUD_DEV_DOCKER_MCP_CONFIG"] = json.dumps(mcp_config)
+
+        # Create FastMCP proxy using the ProxyClient
+        fastmcp_proxy = FastMCP.as_proxy(proxy_client)
 
         # Wrap in MCPServer to get /docs and REST wrappers
         proxy = MCPServer(name="HUD Docker Dev Proxy")
 
+        # Enable logs endpoint on HTTP server
+        os.environ["_HUD_DEV_LOGS_PROVIDER"] = "enabled"
+
         # Import all tools from the FastMCP proxy
         await proxy.import_server(fastmcp_proxy)
 
@@ -693,7 +801,15 @@ def run_docker_dev_server(
         asyncio.run(run_proxy())
     except KeyboardInterrupt:
         hud_console.info("\n\nStopping...")
+        cleanup_container()
         raise typer.Exit(0) from None
+    except Exception:
+        # Ensure cleanup happens on any exception
+        cleanup_container()
+        raise
+    finally:
+        # Final cleanup attempt
+        cleanup_container()
 
 
 def run_mcp_dev_server(
@@ -712,6 +828,20 @@ def run_mcp_dev_server(
     docker_args = docker_args or []
     cwd = Path.cwd()
 
+    # Find an available port if not using stdio transport
+    if not stdio:
+        from hud.cli.utils.logging import find_free_port
+
+        actual_port = find_free_port(port)
+        if actual_port is None:
+            hud_console.error(f"No available ports found starting from {port}")
+            raise typer.Exit(1)
+
+        if actual_port != port:
+            hud_console.info(f"Port {port} is in use, using port {actual_port} instead")
+
+        port = actual_port
+
     # Auto-detect Docker mode if Dockerfile present and no module specified
     if not docker and module is None and should_use_docker_mode(cwd):
         hud_console.note("Detected Dockerfile - using Docker mode with volume mounts")
